# coding: utf-8

"""
    ActivitySmith API

    Send push notifications and Live Activities to your own devices via a single API key.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from activitysmith_openapi.api.live_activities_api import LiveActivitiesApi


class TestLiveActivitiesApi(unittest.TestCase):
    """LiveActivitiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LiveActivitiesApi()

    def tearDown(self) -> None:
        pass

    def test_end_live_activity(self) -> None:
        """Test case for end_live_activity

        End a Live Activity (legacy manual lifecycle)
        """
        pass

    def test_end_live_activity_stream(self) -> None:
        """Test case for end_live_activity_stream

        End a stream
        """
        pass

    def test_reconcile_live_activity_stream(self) -> None:
        """Test case for reconcile_live_activity_stream

        Start a new Live Activity or update an existing one
        """
        pass

    def test_start_live_activity(self) -> None:
        """Test case for start_live_activity

        Start a Live Activity (legacy manual lifecycle)
        """
        pass

    def test_update_live_activity(self) -> None:
        """Test case for update_live_activity

        Update a Live Activity (legacy manual lifecycle)
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ActivitySmith API

    Send push notifications and Live Activities to your own devices via a single API key.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from activitysmith_openapi.models.channel_target import ChannelTarget
from activitysmith_openapi.models.push_notification_action import PushNotificationAction
from typing import Optional, Set
from typing_extensions import Self

class PushNotificationRequest(BaseModel):
    """
    PushNotificationRequest
    """ # noqa: E501
    title: StrictStr
    message: Optional[StrictStr] = None
    subtitle: Optional[StrictStr] = None
    media: Optional[Annotated[str, Field(strict=True)]] = Field(default=None, description="Optional HTTPS URL for an image, audio file, or video that users can preview or play when they expand the notification. If `redirection` is omitted, tapping the notification opens this URL. Cannot be combined with `actions`.")
    redirection: Optional[Annotated[str, Field(strict=True)]] = Field(default=None, description="Optional HTTPS URL opened when user taps the notification body. Overrides the default tap target from `media` when both are provided.")
    actions: Optional[Annotated[List[PushNotificationAction], Field(max_length=4)]] = Field(default=None, description="Optional interactive actions shown when users expand the notification. Cannot be combined with `media`.")
    payload: Optional[Dict[str, Any]] = None
    badge: Optional[StrictInt] = None
    sound: Optional[StrictStr] = None
    target: Optional[ChannelTarget] = None
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["title", "message", "subtitle", "media", "redirection", "actions", "payload", "badge", "sound", "target"]

    @field_validator('media')
    def media_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^https:\/\/", value):
            raise ValueError(r"must validate the regular expression /^https:\/\//")
        return value

    @field_validator('redirection')
    def redirection_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^https:\/\/", value):
            raise ValueError(r"must validate the regular expression /^https:\/\//")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PushNotificationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in actions (list)
        _items = []
        if self.actions:
            for _item in self.actions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['actions'] = _items
        # override the default output from pydantic by calling `to_dict()` of target
        if self.target:
            _dict['target'] = self.target.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PushNotificationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "title": obj.get("title"),
            "message": obj.get("message"),
            "subtitle": obj.get("subtitle"),
            "media": obj.get("media"),
            "redirection": obj.get("redirection"),
            "actions": [PushNotificationAction.from_dict(_item) for _item in obj["actions"]] if obj.get("actions") is not None else None,
            "payload": obj.get("payload"),
            "badge": obj.get("badge"),
            "sound": obj.get("sound"),
            "target": ChannelTarget.from_dict(obj["target"]) if obj.get("target") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    ActivitySmith API

    Send push notifications and Live Activities to your own devices via a single API key.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from activitysmith_openapi.api.metrics_api import MetricsApi


class TestMetricsApi(unittest.TestCase):
    """MetricsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MetricsApi()

    def tearDown(self) -> None:
        pass

    def test_update_metric_value(self) -> None:
        """Test case for update_metric_value

        Update a widget metric value
        """
        pass


if __name__ == '__main__':
    unittest.main()
